shell

package
v0.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Overview

Package shell provides the implementation of a shell test script.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(logger logr.Logger, beforeScript, afterScript *string) test.Script

New creates a new shell script by merging beforeScript and afterScript. Since the "before" and "after" are part of the same shell script, it is possible to reuse the declarations/definitions of the "before" part in the "after" part.

Types

This section is empty.

Jump to