Documentation
¶
Overview ¶
Package syscall provides the definition of a Syscall test step and a syscall test step Builder.
Index ¶
Constants ¶
const ( // NameWrite specifies the name of the write system call test step. NameWrite = "write" // NameRead specifies the name of the read system call test step. NameRead = "read" // NameOpen specifies the name of the open system call test step. NameOpen = "open" // NameOpenAt specifies the name of the openat system call test step. NameOpenAt = "openat" // NameOpenAt2 specifies the name of the openat2 system call test step. NameOpenAt2 = "openat2" // NameSymLink specifies the name of the symlink system call test step. NameSymLink = "symlink" // NameSymLinkAt specifies the name of the symlinkat system call test step. NameSymLinkAt = "symlinkat" // NameLink specifies the name of the link system call test step. NameLink = "link" // NameLinkAt specifies the name of the linkat system call test step. NameLinkAt = "linkat" // NameInitModule specifies the name of the init_module system call test step. NameInitModule = "init_module" // NameFinitModule specifies the name of the finit_module system call test step. NameFinitModule = "finit_module" // NameDup specifies the name of the dup system call test step. NameDup = "dup" // NameDup2 specifies the name of the dup2 system call test step. NameDup2 = "dup2" // NameDup3 specifies the name of the dup2 system call test step. NameDup3 = "dup3" // NameConnect specifies the name of the connect system call test step. NameConnect = "connect" // NameSocket specifies the name of the socket system call test step. NameSocket = "socket" // NameSendTo specifies the name of the sendto system call test step. NameSendTo = "sendto" // NameKill specifies the name of the kill system call test step. NameKill = "kill" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Builder ¶
type Builder interface {
// Build builds a new Syscall based on the provided name and description.
Build(name Name, stepName string, description *Description) (Syscall, error)
}
Builder allows to build new syscall test steps.
type Description ¶
type Description struct {
RawArgs map[string]any
FieldBindings []*step.FieldBinding
}
Description contains information to build a new Syscall test step.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package base provides the definition of a generic syscall.Syscall test step.
|
Package base provides the definition of a generic syscall.Syscall test step. |
|
Package builder provides the implementation of a syscall.Builder.
|
Package builder provides the implementation of a syscall.Builder. |
|
Package connect provides the implementation of a connect system call test step.
|
Package connect provides the implementation of a connect system call test step. |
|
Package dup provides the implementation of a dup system call test step.
|
Package dup provides the implementation of a dup system call test step. |
|
Package dup2 provides the implementation of a dup2 system call test step.
|
Package dup2 provides the implementation of a dup2 system call test step. |
|
Package dup3 provides the implementation of a dup3 system call test step.
|
Package dup3 provides the implementation of a dup3 system call test step. |
|
Package finitmodule provides the implementation of an finit_module system call test step.
|
Package finitmodule provides the implementation of an finit_module system call test step. |
|
Package initmodule provides the implementation of an init_module system call test step.
|
Package initmodule provides the implementation of an init_module system call test step. |
|
Package kill provides the implementation of a kill system call test step.
|
Package kill provides the implementation of a kill system call test step. |
|
Package link provides the implementation of a link system call test step.
|
Package link provides the implementation of a link system call test step. |
|
Package linkat provides the implementation of a linkat system call test step.
|
Package linkat provides the implementation of a linkat system call test step. |
|
Package open provides the implementation of an open system call test step.
|
Package open provides the implementation of an open system call test step. |
|
Package openat provides the implementation of an openat system call test step.
|
Package openat provides the implementation of an openat system call test step. |
|
Package openat2 provides the implementation of an openat2 system call test step.
|
Package openat2 provides the implementation of an openat2 system call test step. |
|
Package read provides the implementation of a write system call test step.
|
Package read provides the implementation of a write system call test step. |
|
Package sendto provides the implementation of a sendto system call test step.
|
Package sendto provides the implementation of a sendto system call test step. |
|
Package socket provides the implementation of a socket system call test step.
|
Package socket provides the implementation of a socket system call test step. |
|
Package symlink provides the implementation of a symlink system call test step.
|
Package symlink provides the implementation of a symlink system call test step. |
|
Package symlinkat provides the implementation of a symlinkat system call test step.
|
Package symlinkat provides the implementation of a symlinkat system call test step. |
|
Package write provides the implementation of a write system call test step.
|
Package write provides the implementation of a write system call test step. |
Click to show internal directories.
Click to hide internal directories.